@@ -32,7 +32,23 @@ test.initialSearch.folded <- function() {
 
 test.initialSearch.smoothing <- function() {
   jaatha <- Jaatha.initialize(dm.tt, sum.stats.tt, 30, smoothing=TRUE)
+  jaatha <- Jaatha.initialSearch(jaatha, sim=50, blocks.per.par=1)
+  pStartPoints <- Jaatha.getStartingPoints(jaatha)
+  #checkEquals(1, nrow(pStartPoints))
+}
+
+test.initialSearch.fpc <- function() {
+  jaatha <- Jaatha.initialize(dm.fpc, sum.stats.fpc, 1234, cores=2)
   jaatha <- Jaatha.initialSearch(jaatha, sim=20, blocks.per.par=2)
   pStartPoints <- Jaatha.getStartingPoints(jaatha)
-  checkEquals(4, nrow(pStartPoints))
+  checkEquals(6, nrow(pStartPoints))
 }
+
+test.initialSearch.fpc_groups <- function() {
+  set.seed(1234)
+  dm <- dm.addSampleSize(dm.fpc, 11:12, group = 2)
+  dm <- dm.addSampleSize(dm, 5:6, group = 3)
+  sum.stats <- dm.simSumStats(dm.addSummaryStatistic(dm, 'seg.sites'), c(1, 2, 5))
+  jaatha.fpc <- Jaatha.initialize(dm, sum.stats, 123)
+  jaatha.fpc <- Jaatha.initialSearch(jaatha.fpc, sim=20, blocks.per.par=2)
+}
\ No newline at end of file
